Enum diem_key_manager::Action[][src]

pub enum Action {
    NoAction,
    FullKeyRotation,
    SubmitKeyRotationTransaction,
    WaitForReconfiguration,
    WaitForTransactionExecution,
}
Defines actions that KeyManager should perform after a check of all associated state.

Variants

NoAction

There is no need to perform a rotation (keys are still fresh).

FullKeyRotation

Sufficient time has passed for another key rotation (keys are stale).

SubmitKeyRotationTransaction

Storage and the blockchain are inconsistent, submit a new rotation transaction.

WaitForReconfiguration

The validator config and the validator set are inconsistent, wait for reconfiguration.

WaitForTransactionExecution

Storage and the blockchain are inconsistent, wait for rotation transaction execution.