Enum diem_key_manager::Action [−][src]
pub enum Action {
NoAction,
FullKeyRotation,
SubmitKeyRotationTransaction,
WaitForReconfiguration,
WaitForTransactionExecution,
}Expand description
Defines actions that KeyManager should perform after a check of all associated state.
Variants
There is no need to perform a rotation (keys are still fresh).
Sufficient time has passed for another key rotation (keys are stale).
Storage and the blockchain are inconsistent, submit a new rotation transaction.
The validator config and the validator set are inconsistent, wait for reconfiguration.
Storage and the blockchain are inconsistent, wait for rotation transaction execution.